from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\xe2\x07\x00\x00\x00\x00\x00\x18\x7d\x2e\x35\x8c\x8a\x8c\xe0\xf4\x0e\x10\x6e\x21\x17\xb9\x9e\xf3\x00\x00\x00\x00\x00\x00\x00\x00\x25\x13\x7f\x25\xcf\xdf\xce\x82\x02\x30\x87\x39\xb1\x97\x40\xb3\xd2\x81\x7e\x06\x34\x02\xe7\xcb\xb5\xd5\x03\xf7\xa5\xc9\x97\x6d\xea\xb7\x87\x11\xa2\x5c\xc8\x04\x30\x5a\x84\x55\x79\xd7\x3b\x09\x0d\xaf\x1b\x91\x9f\x4d\x11\x91\xd0\xe7\xe7\x49\xdf\x00\x52\x81\x19\x64\x99\x47\xe8\x6f\xaa\xc8\x2d\xc1\x75\x34\xd9\x6d\xc5\x0c\x25\x67\x24\x0c\x83\x25\x7d\xde\xcf\x40\x2f\x1b\xe7\x8a\x15\x3f\xa5\xce\x3f\x93\xae\x67\xda\xa8\x8f\x6d\x5d\xba\x97\xaf\x12\x0d\x37\xfc\x90\x54\x7c\x36\x8b\xe3\xd7\x2d\xe3\x1f\xf4\xe6\xf4\xcc\x8a\x5a\xec\x33\x2b\x69\x2d\xed\x8b\x20\xc6\xf6\x36\x1e\x64\x62\xcf\x84\x42\x7c\xef\xaa\xdc\x99\x8b\x61\x00\x98\x53\xc4\x74\xca\xf2\x75\xcb\x4c\xa0\xc0\x3f\x99\x20\x66\xee\x3b\x91\x42\x5f\x6d\x02\xb0\xcb\x0b\x45\x74\x58\xe7\xbd\x14\x4b\x8f\x3e\x04\x53\xca\x2e\xa9\x96\x8b\xce\x29\x82\x6e\xf2\x43\x74\x33\xda\xfc\x38\x5b\x18\x53\x83\x99\x12\x93\xe8\x02\x2c\x5f\x8a\x8f\x52\x8b\x24\x4e\xe1\xa5\xd5\xd4\xad\x09\x47\xce\x65\x7c\xad\xb0\xce\x17\x7b\x1d\x1c\x50\xf6\xfd\x32\x8e\x90\x55\x14\x73\x05\xc3\xc7\xae\xcd\x5f\x3b\x95\x8f\xa6\xd3\xa4\x75\x58\x0a\x62\xb9\x86\xe1\x9d\xf5\x9b\x85\xa3\x31\x52\x05\xeb\x79\xdf\x16\xc2\x91\xb2\xe2\x93\xc8\xc1\x52\x28\xc3\x80\xe1\x38\x50\xfe\x57\x96\x42\x98\x09\x97\xc7\x01\x1d\x2c\x30\x27\xc7\xd8\xe1\xa9\x25\x9f\xa5\xfc\x07\x5f\xc5\xa6\x20\xcc\x80\x44\xc0\x44\x48\x39\x35\xfb\xa2\xfe\xa8\xa4\x4a\x4b\x85\x53\x01\xc5\xee\x60\x26\x7f\xa0\xd6\x0b\xe2\x98\x84\x7d\xfa\xe1\x9f\x85\xb6\xdf\xf2\x0a\xb5\x78\x44\x40\x39\xea\x07\xc0\xf9\x6a\x76\xa8\x1c\x83\x76\xc4\x81\x6b\xaa\xb3\x8a\x29\x00\x21\x69\x8c\x49\xf5\x47\x62\xaa\xaf\x84\xfe\x90\x87\xd8\x10\x48\xdf\x88\x1c\x8e\x8d\xf0\xb1\xae\x2e\xc3\x8d\x23\xf1\x0f\x4a\xd6\x81\xfd\x6b\xc4\x38\x03\xf6\xe0\x7d\xf4\xdd\x1c\x91\x9d\x5c\x45\x46\xbd\x35\x2e\x69\x75\x21\xf6\x17\x87\x16\xa4\x88\xe6\xb9\xa6\xa1\xae\x5d\xc2\x0b\x2d\xa8\x05\xd6\xd3\x91\x74\xca\x61\xf6\x63\x4a\xe3\xc3\xb8\xc2\x21\x2d\xdc\x89\x51\xda\xb2\x16\x66\x79\x22\xb8\x37\xbc\x9f\xd5\x14\xe9\xfa\x34\x84\xbb\x82\x49\xd5\x3b\x94\x30\xa6\xfe\x2e\xb2\x15\x43\xa3\x43\x8f\xb1\xbd\x5c\x2d\x93\xd8\x5a\x12\xd2\x2e\x25\xbd\x1c\xfe\xda\x99\x04\x54\xf9\xb3\x92\x8a\x0e\xed\x9a\x4c\x6e\x79\xbf\x1c\x00\x9a\x30\x98\x19\xa6\xda\x47\x4c\x00\x44\xb2\xf4\x80\x51\x68\xd0\x27\xb0\x4e\x78\x73\xf2\xca\x88\xb0\xfd\xc6\x6d\xe3\x33\xa3\xd1\xac\xf2\x9f\x30\xcf\x8d\x0c\xb2\x6d\x2b\x20\x63\x38\x71\x9a\x9d\x0e\xf5\x7c\xaa\x6a\x6a\x2d\x14\x48\x5c\xa7\xea\xfb\x89\xd4\x17\x7e\xce\x39\xee\xab\x99\x2f\x3e\x40\xfa\xd9\x6f\x3e\xb6\xb2\x1f\x13\xc3\xb2\xff\x9a\xc1\xc9\x74\xca\x3b\x84\x89\xc5\x0f\xe6\xe0\x58\x3d\xbc\x36\x29\xd6\x95\xc2\x78\x76\x10\xc9\x7b\x56\x3b\xe7\x11\x92\x73\x19\x39\xff\xf3\xee\x26\x57\x46\x0e\x2f\x43\xd2\x46\x47\x80\x51\x10\x30\x00\x56\xd1\x53\xc4\x00\x88\x67\xff\xa4\xe3\x2f\xc5\xb2\x44\x31\x37\xf4\x3a\x1d\x59\x0f\xd9\x68\xc1\xb0\x81\xa9\x7c\x4b\x7e\xd8\xb3\xcc\x52\x5c\xb1\x44\x6e\xca\xc6\xb6\x3f\xb5\x89\xea\x52\x37\x59\xa6\xf9\x0a\xc0\xe2\x28\xc0\xe6\x9b\x69\x6f\x38\x8c\x8f\xd0\x77\x57\x06\x5b\xc0\xd7\x45\x10\x3c\xf9\x98\xdc\xbf\xb2\xac\x07\x52\x0e\x44\xd0\x57\x8c\x33\x6d\x81\xd7\x0b\x85\xe5\x63\x67\xcd\x24\x2d\xba\x2f\x01\xa7\x3d\xda\x7c\xe0\x69\xf0\xe4\x4d\x8a\x69\xa9\xc0\xe4\x8a\xa4\x9f\x49\xab\x70\x89\xc5\x9a\x1c\xdb\x06\x94\x69\x9b\xcf\xb5\xc0\x6a\xbf\x25\x0a\x48\x4d\x31\x2a\xf6\xb9\xf7\x8f\xf3\x1c\xa4\x6f\x1c\xe5\x03\x80\x34\x5e\x67\xc5\x42\x37\x07\xe0\xb4\x51\xda\x51\x44\x77\xc2\x76\xeb\x3c\xe8\x30\x80\x73\x8c\x37\x14\x6d\x7a\x86\x10\x6f\xd4\xcb\xdf\x75\x5a\x5e\xc6\x91\x9e\x54\xa7\xc0\x9b\xfd\xe8\x3f\x85\xf3\xbf\xb6\xdc\x9c\x50\xac\x51\xd5\xa1\x8e\xef\x0a\x93\x2a\x8f\xe0\xab\xaa\x69\xc6\x33\xc2\x8b\x37\xe4\xa6\x2a\x40\xcd\xaa\x3f\xd5\xd2\xd8\xb2\xbe\xd8\xe6\x2e\x3c\x45\x3f\xf4\x12\x46\xd1\xc4\x86\xf7\x0f\xce\x79\xb0\x42\x0e\x46\x2d\xa2\x4c\xf3\x86\xdb\xac\x15\x9d\x85\xde\x9d\xa8\x54\xa6\x23\x54\x06\x29\x03\xbb\x55\xa0\x94\xa8\xe6\x60\x51\xf1\xe0\x9a\x19\x89\x74\x5b\xb2\x5b\xe3\x39\x50\xcb\x2f\xbe\xca\x38\xcc\x01\x42\x1e\x8d\x80\x1a\x47\xda\x28\x6e\x09\x32\xfd\x69\xd2\x8f\x71\x6d\x3b\xba\x38\x15\xaf\x8d\x45\xf7\xc3\x03\xeb\x4e\xc9\x8c\xce\x25\xd4\x0b\x69\x6b\xec\x1f\x30\xe9\x66\x4d\x9c\x8d\xee\x9a\xe8\x12\x0f\x9e\xa5\xae\xe6\x72\xf9\x98\x5d\x8d\x55\x94\x04\x7b\xdc\xd8\x62\x6d\x1b\x67\x93\xc9\xdd\xbb\x8c\x26\x0c\x4f\x9e\x8a\x2e\x81\x33\x3a\x07\x0e\xaf\x4a\xb4\x76\x19\x66\xc1\x92\xcb\x5f\xe5\x1c\xf4\xe9\xd8\x31\x48\x2a\xbe\x74\x15\xab\xee\x65\x78\x53\x46\x53\xfa\x4e\xce\xdc\x21\x86\x49\x67\x42\x2f\xc8\x2f\xe1\x7c\xa2\x70\x97\x08\x8d\xb8\x9a\x3d\x10\xaf\x84\x28\xc1\x05\x01\xdd\xa2\xda\xcd\x72\x4c\xd3\x0e\x97\x20\xa3\x1e\xf5\x56\x6b\x7f\xc1\xe2\xc7\xe6\x5f\x23\xee\x91\xbf\x69\xb2\x1c\xd1\xb5\x35\x00\x77\xb5\xc3\x47\x1f\x1c\x72\x26\x2c\x86\x09\x04\x94\x33\x89\x15\x91\x47\x45\x28\x67\x62\x06\x14\x29\xdc\x0f\xf9\x96\x0f\xa3\x2f\x76\x12\xb0\x85\xcf\xf9\x2b\xae\x26\x79\x47\x50\x02\x1c\x32\xc1\x9d\x25\xa1\x5e\x82\x75\xe7\x81\x79\xb8\x58\x0c\xce\x23\x3b\x70\x66\xeb\xa2\x6e\xa4\x6f\x95\xf8\x35\xbb\x81\xab\xcf\xc3\x0f\x8d\x97\xc2\xb0\x22\x44\xac\x35\xe0\x05\x0a\xff\x05\xd5\x30\xc1\xfb\x89\x08\xf1\xa0\xf5\x7a\x76\x70\xf4\xa3\x0e\x42\xed\x02\xe8\x69\x52\xfa\xc9\xc7\x7a\x92\x69\x7f\x9d\x50\x90\x3a\xea\x3d\x81\x0a\xe2\xa5\xc6\xc2\x3f\x39\xbd\x64\x60\x41\xfc\xe0\x13\xc0\xd9\x3b\x5d\xad\x83\xa1\x48\xca\xd0\xe6\x7e\x67\xe4\x68\xb8\x47\x96\x7a\xe0\x92\x94\x3d\x64\xb3\x42\x75\xec\xdf\xa1\xb1\x4e\xc7\xa1\x4c\x0f\x91\x5b\xc2\x86\xab\xe6\xb3\xbc\x1c\x68\x9f\x07\x45\xda\xb6\xe8\xde\x13\xea\x2b\xb1\xc7\x9c\x71\x30\xcb\x36\x1e\xf5\x34\x0d\x1e\xef\x19\x98\x9b\x2f\x8f\x2b\xc6\x66\x94\x31\x03\xa7\x4e\x53\xcd\x86\x63\x2b\xe4\x89\xfc\x19\xe6\x5f\xa0\x15\x88\x07\xbc\x86\x41\xf5\x3e\xc7\xd4\xf0\x55\xa6\xab\xf8\xe8\x44\x79\xab\xe7\xc0\xf0\xa9\x29\xf9\xd5\x9b\x83\xef\xf8\x03\x38\xcb\x7f\x51\x1c\xca\xd9\x47\x03\xb9\x22\x12\x44\x45\x31\x37\x1e\x2b\xc3\x6d\xd1\xa2\x08\xe1\x45\x5e\xa3\x8f\x8d\x57\x17\xb3\x5e\x30\xcb\x4f\x66\x9d\xac\x93\xa7\x17\x7f\xb1\x14\x26\x4e\x3d\x81\x1c\x19\x5b\x73\xc5\x18\xd5\x53\xe0\x6f\x07\xaf\x33\xd6\xe9\xa3\xb7\xed\xa1\xed\x78\x0e\xd3\x38\xba\x18\x20\xed\x06\xa6\xdc\x4b\x46\x0e\x64\x72\xce\x1a\x9b\x6c\x39\xb8\xeb\xaf\xbe\xd3\x8e\xd9\xf6\x12\xda\x01\x19\xad\x2d\xe0\x89\xb7\x4f\xf1\x6f\xff\x35\xd4\xde\x87\x3e\x59\x4a\x9b\xfb\xa3\xfb\x6c\xa6\x5a\xae\xe2\xde\x6e\xf8\xdd\x1f\x06\xdc\xf5\x5c\xbc\x8c\xfd\x05\xb6\x9b\x87\xd9\x74\xbe\xf1\x38\x87\xe9\xd4\xa5\x5b\xeb\xf9\x8b\x17\x40\xd1\x8b\xc8\x43\xf5\x1c\x8b\xa6\xc4\x84\x29\xb8\xd0\x53\x59\xef\xe6\x94\x85\x84\x90\x88\xda\x56\x3c\xad\x8c\x9b\x8f\x19\xa2\xb2\x6d\x8a\xdd\x0b\x85\xa4\x55\xde\x5d\x63\xbb\xd1\x65\x91\x04\x30\xa8\xfc\xa3\xc2\x30\x7c\xad\x24\xba\x37\xbc\x19\x7d\x58\x8f\xcc\xa2\x20\x85\xc2\xec\x0a\xd6\xc0\xaf\xcd\xc4\x8c\x61\x42\x27\xca\x71\x71\x68\xb4\xbf\xad\xa6\x24\xa7\x53\x82\x7e\x63\xde\x06\xe9\x29\x99\xba\x7a\x52\xda\x04\x23\x53\xf1\xf6\x10\x70\xc7\x3c\x18\xad\x7e\x27\x0a\xf0\x04\xf5\x8e\x3b\x05\x6b\x33\x19\x95\x10\x31\xc4\x27\x4e\xac\xc4\x78\xd1\x15\xfd\x5d\xfb\x37\xb4\x9c\xa4\x22\xda\x6b\x84\xb0\x6c\xe2\x1a\x81\x89\x37\xcb\xfd\x1a\x70\x10\xe2\x1f\xa7\x0b\x74\xa1\x68\x15\x75\x4b\x2c\x29\x8c\x90\x45\xfe\xf3\x8a\x54\x47\xb6\x1f\x56\x03\x18\xa6\x72\xb2\xef\xa3\xd2\x1b\x68\xb1\x50\x91\xad\xa1\xac\xeb\xb3\xf1\x0b\x57\x99\xe0\x82\x4a\x25\xf9\x1d\xb4\x61\x48\xa6\x8c\x68\x57\x4a\xa4\xb2\x8e\x1e\x09\x11\x7e\x34\xc5\xa3\xc0\x18\x00\x7e\x3e\x45\xf0\x47\xd8\x77\xf3\x01\xdf\x82\x0f\x0f\x1a\x53\xd5\xa3\xd1\x06\x0e\x48\xf4\x48\x7d\xb1\xea\x5b\x67\x9b\x2d\x81\xb3\x55\x76\x6c\x17\xcf\x32\xc8\x79\x31\xd3\x60\xfd\x64\xc1\x0f\x77\x5c\x4f\xe6\xfc\x68\x9f\x3d\x9e\x52\xb8\x08\xf2\xcc\xf6\xc8\x49\xc2\xb0\x01\x31\x58\x7f\xef\xa5\x49\xc7\x4c\x66\x35\x97\xbc\x32\xc0\xb6\x7b\x9c\xd2\x61\x00\x3c\x02\xc3\x2f\xe7\xeb\xcc\xc5\x57\x40\x6c\x09\x71\x8e\x5c\xa2\x6e\x0e\xe5\xca\x4f\x41\x98\x27\x80\x77\x2b\x59\x3f\x7a\x13\xef\xa0\x8d\x20\xda\xbf\x71\x72\xeb\x84\x17\xa8\x44\x9f\x15\x7c\x12\xbb\x5e\x66\x2d\x89\xda\xc2\xb6\xc2\xd7\x53\x6e\xf8\x80\xb5\xd5\x67\xa5\xfe\xdc\x47\xa2\x9c\xfd\x35\x7f\x50\xce\x7b\xe2\xe2\x59\x09\x19\x60\x91\xbd\xd8\x71\x76\x13\x19\x25\x84\xd7\x19\xe6\x1f\x2a\xc1\x33\xb5\xfb\x10\x20\x6b\x61\xd3\x42\xc4\x80\x47\x3f\x86\x5a\x2b\x4f\x3c\xe5\x96\x59\x2d\x60\xa0\xe3\xd9\xd7\xed\xbf\x83\xbb\x40', 2)

# cleanup
del pyarmor_runtime

